positionOf property
Reads the current continuous page position.
The callback owns any guarding its source needs (e.g. a PageController before its first layout has no page yet and should report a fallback).
Implementation
final ValueGetter<double> positionOf;